searchData={"items":[{"type":"module","title":"Mentat","doc":"[![Elixir CI](https://github.com/keathley/mentat/workflows/Elixir%20CI/badge.svg)](https://github.com/keathley/mentat/actions)\n[![Module Version](https://img.shields.io/hexpm/v/mentat.svg)](https://hex.pm/packages/mentat)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/mentat/)\n[![Total Download](https://img.shields.io/hexpm/dt/mentat.svg)](https://hex.pm/packages/mentat)\n[![License](https://img.shields.io/hexpm/l/mentat.svg)](https://github.com/keathley/mentat/blob/main/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/keathley/mentat.svg)](https://github.com/keathley/mentat/commits/main)\n\nProvides a super simple cache with ttls.","ref":"Mentat.html"},{"type":"module","title":"Usage - Mentat","doc":"A cache must be given a name when its started.\n\n```elixir\nMentat.start_link(name: :my_cache)\n```\n\nAfter its been started you can store and retrieve values:\n\n```elixir\nMentat.put(:my_cache, user_id, user)\nuser = Mentat.get(:my_cache, user_id)\n```","ref":"Mentat.html#module-usage"},{"type":"module","title":"TTLs - Mentat","doc":"Both `put` and `fetch` operations allow you to specify the key's TTL. If no\nTTL is provided then the TTL is set to `:infinity`. TTL times are always\nin milliseconds.\n\n```elixir\nMentat.put(:my_cache, :key, \"value\", [ttl: 5_000])\n\nMentat.fetch(:my_cache, :key, [ttl: 5_000], fn key ->\n  {:commit, \"value\"}\nend)\n```\n\n#","ref":"Mentat.html#module-ttls"},{"type":"module","title":"Default TTLs - Mentat","doc":"You can set a global TTL for all new keys","ref":"Mentat.html#module-default-ttls"},{"type":"module","title":"Limits - Mentat","doc":"Mentat supports optional limits per cache.\n\n```elixir\nMentat.start_link(name: LimitedCache, limit: [size: 100])\n```\n\nWhen the limit is reached, the janitor will asynchronously reclaim a percentage of the keys.","ref":"Mentat.html#module-limits"},{"type":"module","title":"Telemetry - Mentat","doc":"Mentat publishes multiple telemetry events.\n\n  * `[:mentat, :get]` - executed after retrieving a value from the cache.\n    Measurements are:\n\n    * `:status` - Can be either `:hit` or `:miss` depending on if the key was\n      found in the cache.\n\n    Metadata are:\n\n      * `:key` - The key requested\n      * `:cache` - The cache name\n\n  * `[:mentat, :put]` - executed when putting a key into the cache. No\n    measurements are provided.\n\n    Metadata are:\n\n      * `:key` - The key requested\n      * `:cache` - The name of the cache\n\n  * `[:mentat, :janitor, :cleanup]` - executed after old keys are cleaned\n    from the cache. Measurements are:\n\n    * `:duration` - the time it took to clean up the old keys. Time is\n      in `:native` units.\n    * `total_removed_keys` - The count of keys removed from the cache.\n\n    Metadata are:\n\n      * `cache` - The cache name.","ref":"Mentat.html#module-telemetry"},{"type":"module","title":"Contracts - Mentat","doc":"Mentat supports `Oath` contracts. This helps ensure that you're using Mentat correctly\nand that Mentat is returning what you expect. You can enable contracts by setting\n\n```elixir\nconfig :oath,\n  enable_contracts: true\n```\n\nAnd then recompiling Mentat in dev and test environments:\n\n```\nMIX_ENV=dev mix deps.compile mentat --force\nMIX_ENV=test mix deps.compile mentat --force\n```","ref":"Mentat.html#module-contracts"},{"type":"module","title":"Installation - Mentat","doc":"```elixir\ndef deps do\n  [\n    {:mentat, \"~> 0.7\"}\n  ]\nend\n```","ref":"Mentat.html#module-installation"},{"type":"module","title":"Should I use this? - Mentat","doc":"There are (many) other caching libraries out there that provide many more features\nthan Mentat. But, it turns out, I don't need most of those features. Mentat is\nintended to be very small while still providing the necessary components. The\ntest suite is sparse, but we've been using this implementation in production\nfor a while now so I feel pretty confident in it.","ref":"Mentat.html#module-should-i-use-this"},{"type":"function","title":"Mentat.delete/2","doc":"Deletes a key from the cache","ref":"Mentat.html#delete/2"},{"type":"function","title":"Mentat.fetch/4","doc":"Fetches a value or executes the fallback function. The function can return\neither `{:commit, term()}` or `{:ignore, term()}`. If `{:commit, term()}` is\nreturned, the value will be stored in the cache before its returned. See the\n\"TTLs\" section for a list of options.\n\nSince `fetch` is logically the same as a `get` (and also a `put` if\n`{:commit, term()}` is returned from the fallback function), it shares the\nsame Telemetry events (`[:mentat, :get]` and `[:mentat, :put]`).","ref":"Mentat.html#fetch/4"},{"type":"function","title":"Example - Mentat.fetch/4","doc":"```\nMentat.fetch(:cache, user_id, fn user_id ->\n  case get_user(user_id) do\n    {:ok, user} ->\n      {:commit, user}\n\n    error ->\n      {:ignore, error}\n  end\nend)\n```","ref":"Mentat.html#fetch/4-example"},{"type":"function","title":"Mentat.get/2","doc":"Retrieves a value from a the cache. Returns `nil` if the key is not found.","ref":"Mentat.html#get/2"},{"type":"function","title":"Mentat.init/1","doc":"","ref":"Mentat.html#init/1"},{"type":"function","title":"Mentat.keys/2","doc":"Returns a list of all keys. By default this function only returns keys\nthat have no exceeded their TTL. You can pass the `all: true` option to the function\nin order to return all present keys, which may include keys that have exceeded\ntheir TTL but have not been purged yet.","ref":"Mentat.html#keys/2"},{"type":"function","title":"Mentat.purge/1","doc":"Removes all keys from the cache.","ref":"Mentat.html#purge/1"},{"type":"function","title":"Mentat.put/4","doc":"Puts a new key into the cache. See the \"TTLs\" section for a list of\noptions.","ref":"Mentat.html#put/4"},{"type":"function","title":"Mentat.start_link/1","doc":"Starts a new cache.\n\nOptions:\n* `:name` - the cache name as an atom. required.\n* `:cleanup_interval` - How often the janitor process will remove old keys. Defaults to 5_000.\n* `:ets_args` - Additional arguments to pass to `:ets.new/2`.\n* `:ttl` - The default ttl for all keys. Default `:infinity`.\n* `:limit` - Limits to the number of keys a cache will store. Defaults to `:none`.\n  * `:size` - The maximum number of values to store in the cache.\n  * `:reclaim` - The percentage of keys to reclaim if the limit is exceeded. Defaults to 0.1.","ref":"Mentat.html#start_link/1"},{"type":"function","title":"Mentat.stop/1","doc":"","ref":"Mentat.html#stop/1"},{"type":"function","title":"Mentat.touch/2","doc":"Updates a keys inserted at time. This is useful in conjunction with limits\nwhen you want to evict the oldest keys. Returns `true` if the key was found\nand `false` if it was not.","ref":"Mentat.html#touch/2"},{"type":"type","title":"Mentat.cache_opts/0","doc":"","ref":"Mentat.html#t:cache_opts/0"},{"type":"type","title":"Mentat.key/0","doc":"","ref":"Mentat.html#t:key/0"},{"type":"type","title":"Mentat.name/0","doc":"","ref":"Mentat.html#t:name/0"},{"type":"type","title":"Mentat.put_opts/0","doc":"","ref":"Mentat.html#t:put_opts/0"},{"type":"type","title":"Mentat.value/0","doc":"","ref":"Mentat.html#t:value/0"}],"content_type":"text/markdown"}